@@ -28,16 +28,18 @@ class TracPost(Plugin):
     def is_configured(self, project):
         return all((self.get_option(k, project) for k in ('xmlrpc_url')))
 
-    def post_process(self, group, event, is_new, **kwargs):
-        if not is_new or not self.is_configured(event.project):
+    def view(self, request, group, **kwargs):
+        if not self.is_configured(group.project):
             return
-        rpc_srv = xmlrpclib.ServerProxy(self.get_option('xmlrpc_url', project),allow_none=True)
+        rpc_srv = xmlrpclib.ServerProxy(self.get_option('xmlrpc_url', group.project),allow_none=True)
         socket.setdefaulttimeout(30)
 	attrs = {'priority':"minor"}
-	if event.message != None:
+	if group.message != None:
 		pp = pprint.PrettyPrinter(indent=4)
-	       	ticket_id = rpc_srv.ticket.create(event.message, "{{{\n" + str(pp.pformat(event.data)) + "\n}}}\n\nSee Sentry Page @ http://sentry.joinerysoft-directory.co.uk/jms/group/" + str(event.group_id), {'priority':"minor",}, False)
+	       	ticket_id = rpc_srv.ticket.create(group.message, "{{{\n" + str(pp.pformat(group.data)) + "\n}}}\n\nSee Sentry Page @ http://sentry.joinerysoft-directory.co.uk/jms/group/" + str(event.group_id), {'priority':"minor",}, False)
 		print "New Ticket - " + str(ticket_id)
-        return
 
+    def actions(self, request, group, action_list, **kwargs):
+	action_list.append(('Send to Trac', 'http://google.com'))
+	return action_list
 
